import java.awt.BorderLayout;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.io.BufferedReader;
import java.io.File;
import java.io.FileReader;
import java.io.IOException;

import javax.swing.JButton;
import javax.swing.JFrame;
import javax.swing.JLabel;
import javax.swing.JOptionPane;
import javax.swing.JPanel;
import javax.swing.JScrollPane;
import javax.swing.JTextArea;


@SuppressWarnings("serial")
public class AdvancedHeaderFooter extends JFrame implements ActionListener
{	
	private static final String BASECODE_LOCATION = "basecode.txt";
	
	// these Text Areas contain the header and footer text, respectively
	private JTextArea pageCode;
	
	private JButton saveButton;
	private JButton resetButton;
	private JButton closeButton;
	
	public AdvancedHeaderFooter() 
	{		
		// initialize the textareas
		pageCode = new JTextArea();
		pageCode.setText(loadText());
		
		JScrollPane pageCodeScroller = new JScrollPane(pageCode, JScrollPane.VERTICAL_SCROLLBAR_AS_NEEDED, JScrollPane.HORIZONTAL_SCROLLBAR_AS_NEEDED);
		pageCodeScroller.getVerticalScrollBar().setUnitIncrement(60);
		pageCodeScroller.getVerticalScrollBar().setBlockIncrement(180);
		
		saveButton = new JButton("Save and Close");
		saveButton.setToolTipText("Save changes and close the page editor");
		saveButton.addActionListener(this);
		
		closeButton = new JButton("Cancel and Close");
		closeButton.setToolTipText("Close the page editor without saving changes");
		closeButton.addActionListener(this);
		
		resetButton = new JButton("Reset Code");
		resetButton.setToolTipText("Rest page code back to default");
		resetButton.addActionListener(this);
		
		JPanel southPanel = new JPanel();
		southPanel.setLayout(new BorderLayout());
		southPanel.add(saveButton, BorderLayout.CENTER);
		southPanel.add(closeButton, BorderLayout.WEST);
		southPanel.add(resetButton, BorderLayout.EAST);
		
		// construct the frame window
		this.setLayout(new BorderLayout());
		this.add(pageCodeScroller, BorderLayout.CENTER);
		this.add(new JLabel("Page HTML Code:"), BorderLayout.NORTH);
		this.add(southPanel, BorderLayout.SOUTH);
		this.setSize(600, 600);
	    this.setDefaultCloseOperation(JFrame.DO_NOTHING_ON_CLOSE);
	}

	public void popUp() 
	{
		// if the pagecode had been altered previously,
		if(InvoiceCreatorGUI.getInstance().isPageSet())
		{
			// get the user's changes
			pageCode.setText(InvoiceCreatorGUI.getInstance().getPageCode());
		}
		
		// become visible
		this.setVisible(true);
	}
	
	public void close()
	{
		// become invisible
		this.setVisible(false);
	}
	
	private String loadText()
	{
		String retVal = new String();
		
		try
		{
			// this file Reader is linked to basecode.txt file
			FileReader infile = new FileReader(new File(BASECODE_LOCATION));
			
			// create a buffered reader with the file
			BufferedReader in = new BufferedReader(infile);
			
			// line will read in each line of the file individually
			String line = null;
			
			// while there are lines to read, read the lines
			while ((line = in.readLine()) != null) 
			{
				retVal += line + '\n';
			} 
			
			// close the file reader
			in.close();
		}
		catch (IOException e) 
		{
			JOptionPane.showMessageDialog(null, "ERROR: The basecode.txt file could not be located");
			retVal = "Default page could not be retrieved...";
		}
		
		return retVal;	
	}

	@Override
	public void actionPerformed(ActionEvent event) 
	{
		JButton button = (JButton)event.getSource();
		
		// if the user clicked the save button
		if(button.equals(saveButton))
		{
			// save the text into the InvoiceCreatorGUI's pageCode string
			InvoiceCreatorGUI.getInstance().setPageCode(pageCode.getText());
			close();
		}
		// if the user clicked the reset button
		else if(button.equals(resetButton))
		{
			// confirm they wish to reset the code
			if(JOptionPane.showConfirmDialog(null, "Are you sure you would like to reset to default? You will lose all unsaved changes...") == JOptionPane.YES_OPTION)
			{
				// reload the basecode text file
				pageCode.setText(loadText());
			}
		}
		// if the user clicked the close button
		else if(button.equals(closeButton))
		{
			// confirm they wish to close without saving
			if(JOptionPane.showConfirmDialog(null, "Are you sure you would like to close without saving? The page code will be reverted back to it's state before you opened this window...") == JOptionPane.YES_OPTION)
			{
				// just close
				close();
			}
		}
		
	}

}
